@@ -569,7 +569,8 @@ static int check_dir(DOS_FS *fs,DOS_FILE **root,int dots)
 	    if (!strncmp((*walk)->dir_ent.name,MSDOS_DOT,MSDOS_NAME)) dot++;
 	    else dotdot++;
 	}
-	if (bad_name((*walk)->dir_ent.name)) {
+	if (!((*walk)->dir_ent.attr & ATTR_VOLUME) &&
+	    bad_name((*walk)->dir_ent.name)) {
 	    printf("%s\n  Bad file name.\n",path_name(*walk));
 	    if (interactive)
 		printf("1) Drop file\n2) Rename file\n3) Auto-rename\n"
@@ -593,10 +594,12 @@ static int check_dir(DOS_FS *fs,DOS_FILE **root,int dots)
 		    break;
 	    }
 	}
-	skip = 0;
+	/* don't check for duplicates of the volume label */
+	skip = !!((*walk)->dir_ent.attr & ATTR_VOLUME);
 	scan = &(*walk)->next;
 	while (*scan && !skip) {
-	    if (!strncmp((*walk)->dir_ent.name,(*scan)->dir_ent.name,MSDOS_NAME
+	    if (!((*scan)->dir_ent.attr & ATTR_VOLUME) &&
+		!strncmp((*walk)->dir_ent.name,(*scan)->dir_ent.name,MSDOS_NAME
 	      )) {
 		printf("%s\n  Duplicate directory entry.\n  First  %s\n",
 		  path_name(*walk),file_stat(*walk));
